<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:b1e="urn:com.sap.b1i.sim:b1event" xmlns:b1ie="urn:com.sap.b1i.sim:b1ievent" xmlns:bfa="urn:com.sap.b1i.bizprocessor:bizatoms" xmlns:jdbc="urn:com.sap.b1i.adapter:jdbcadapter" xmlns:r3="urn:sap-com:document:sap:rfc:functions" xmlns:vpf="urn:com.sap.b1i.vplatform:entity" xmlns:xci="urn:com.sap.b1i.xcellerator:intdoc" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" bfa:force="" xsi:force="" vpf:force="" xci:force="" b1ie:force="" b1e:force="" jdbc:force="" r3:force="">
  <xsl:param name="offline"/>
  <xsl:variable name="ts" select="document('/com.sap.b1i.internal/xml/timestamp')"/>
  <xsl:variable name="today" select="concat($ts/bfa:timestamp/@year,'-',$ts/bfa:timestamp/@month,'-',$ts/bfa:timestamp/@date)"/>
  <xsl:variable name="now" select="concat($ts/bfa:timestamp/@hour,$ts/bfa:timestamp/@minute)"/>
  <xsl:variable name="Fnow" select="concat($ts/bfa:timestamp/@hour,':',$ts/bfa:timestamp/@minute,':',$ts/bfa:timestamp/@second)"/>
  <xsl:variable name="SIDid" select="/vpf:Msg/vpf:Header/vpf:vBIU/@SId"/>
  <xsl:variable name="SIDdoc" select="document(concat('/com.sap.b1i.vplatform.scenarios.design',$offline,'/vPac.',$SIDid,'/vPac.xml'))"/>
  <xsl:variable name="SIDsetup" select="document(concat('/com.sap.b1i.vplatform.scenarios.setup',$offline,'/vPac.',$SIDid,'/vPac.xml'))"/>
  <xsl:variable name="auth" select="substring-before(substring-after($SIDdoc/vpf:vPac/@Authentication,'('),')')"/>
  <xsl:variable name="userid">
    <xsl:choose>
      <xsl:when test="/vpf:Msg/@test='true'">
        <xsl:value-of select="/vpf:Msg/vpf:Header/vpf:Variables/vpf:var[./@id='userid']/@value"/>
      </xsl:when>
      <xsl:when test="string-length($auth)=0">no_authentication</xsl:when>
      <xsl:otherwise>
        <xsl:variable name="AUTdoc" select="document('/com.sap.b1i.internal.xc/xml/sessioninfo.xml')"/>
        <xsl:value-of select="$AUTdoc/xci:session-info/xci:key[./@name='usrid']/@value"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:variable>
  <xsl:variable name="username">
    <xsl:choose>
      <xsl:when test="/vpf:Msg/@test='true'">
        <xsl:value-of select="/vpf:Msg/vpf:Header/vpf:Variables/vpf:var[./@id='username']/@value"/>
      </xsl:when>
      <xsl:when test="string-length($auth)=0">no_authentication</xsl:when>
      <xsl:otherwise>
        <xsl:variable name="AUTdoc" select="document('/com.sap.b1i.internal.xc/xml/sessioninfo.xml')"/>
        <xsl:value-of select="$AUTdoc/xci:session-info/xci:key[./@name='user']/@value"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:variable>
  <xsl:variable name="setB1ifSndSysId" select="document(concat('/com.sap.b1i.internal.xc/xml/ipobag.xml?B1ifSndSysId=',/vpf:Msg/vpf:Header/vpf:Sender/@Id))"/>
  <xsl:template match="/">
    <Msg xmlns="urn:com.sap.b1i.vplatform:entity">
      <xsl:copy-of select="/vpf:Msg/@*"/>
      <Header>
        <xsl:copy-of select="/vpf:Msg/vpf:Header/*[not(contains('vBIU,Variables,Properties,VarProperties,SysTypeProperties,LocalProperties',local-name()))]"/>
        <vBIU>
          <xsl:attribute name="Id">
            <xsl:value-of select="/vpf:Msg/vpf:Header/vpf:vBIU/@Id"/>
          </xsl:attribute>
          <xsl:attribute name="ver">1.0.0</xsl:attribute>
          <xsl:attribute name="SId">
            <xsl:value-of select="/vpf:Msg/vpf:Header/vpf:vBIU/@SId"/>
          </xsl:attribute>
          <xsl:attribute name="filter">
            <xsl:variable name="biu" select="'cobi.wms.v1.log'"/>
            <xsl:variable name="sender" select="/vpf:Msg/vpf:Header/vpf:Sender/@Id"/>
            <xsl:variable name="FLTsender">
              <xsl:choose>
                <xsl:when test="/vpf:Msg/vpf:Header/vpf:B1OfflineSend/@mode='OfflineSend'">
                  <xsl:value-of select="/vpf:Msg/vpf:Header/vpf:B1OfflineSend/@centralid"/>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:value-of select="$sender"/>
                </xsl:otherwise>
              </xsl:choose>
            </xsl:variable>
            <xsl:variable name="sndfilter" select="$SIDsetup/vpf:vPacSetup/vpf:Publish/vpf:vBIU[./@Id=$biu]/vpf:Sender[./@Id=$FLTsender]/vpf:senderfilter/@filter"/>
            <xsl:variable name="oldfilter" select="/vpf:Msg/vpf:Header/vpf:vBIU/@filter"/>
            <xsl:choose>
              <xsl:when test="string-length($sndfilter)=0 and string-length($oldfilter)=0"/>
              <xsl:when test="string-length($sndfilter)=0 and string-length($oldfilter)&gt;0">
                <xsl:value-of select="$oldfilter"/>
              </xsl:when>
              <xsl:when test="string-length($sndfilter)&gt;0 and string-length($oldfilter)=0">
                <xsl:value-of select="$sndfilter"/>
              </xsl:when>
              <xsl:otherwise>
                <xsl:value-of select="concat($oldfilter, ' and ',$sndfilter)"/>
              </xsl:otherwise>
            </xsl:choose>
          </xsl:attribute>
          <xsl:attribute name="phase">
            <xsl:value-of select="/vpf:Msg/vpf:Header/vpf:vBIU/@phase"/>
          </xsl:attribute>
        </vBIU>
        <xsl:variable name="COBIAppVersion" select="/vpf:Msg/vpf:Body/vpf:Payload[@Role='S']/cobiwms/head/appVersion"/>
        <xsl:variable name="COBIDeviceId" select="/vpf:Msg/vpf:Body/vpf:Payload[@Role='S']/cobiwms/head/deviceId"/>
        <xsl:variable name="COBIProfile" select="/vpf:Msg/vpf:Body/vpf:Payload[@Role='S']/cobiwms/head/profile"/>
        <xsl:variable name="COBISysId" select="/vpf:Msg/vpf:Body/vpf:Payload[@Role='S']/cobiwms/head/sysId"/>
        <xsl:variable name="COBIUserId" select="/vpf:Msg/vpf:Body/vpf:Payload[@Role='S']/cobiwms/head/userId"/>
        <xsl:variable name="COBIFiles">C:\COBI.wms\Files</xsl:variable>
        <xsl:variable name="COBILogs">C:\COBI.wms\Logs</xsl:variable>
        <xsl:variable name="COBIEnablePDNDraft">0</xsl:variable>
        <xsl:variable name="COBIRemPrtPath"/>
        <Variables>
          <var id="userid">
            <xsl:attribute name="value">
              <xsl:value-of select="$userid"/>
            </xsl:attribute>
          </var>
          <var id="username">
            <xsl:attribute name="value">
              <xsl:value-of select="$username"/>
            </xsl:attribute>
          </var>
          <var id="COBIAppVersion">
            <xsl:attribute name="value">
              <xsl:value-of select="$COBIAppVersion"/>
            </xsl:attribute>
          </var>
          <var id="COBIDeviceId">
            <xsl:attribute name="value">
              <xsl:value-of select="$COBIDeviceId"/>
            </xsl:attribute>
          </var>
          <var id="COBIProfile">
            <xsl:attribute name="value">
              <xsl:value-of select="$COBIProfile"/>
            </xsl:attribute>
          </var>
          <var id="COBISysId">
            <xsl:attribute name="value">
              <xsl:value-of select="$COBISysId"/>
            </xsl:attribute>
          </var>
          <var id="COBIUserId">
            <xsl:attribute name="value">
              <xsl:value-of select="$COBIUserId"/>
            </xsl:attribute>
          </var>
        </Variables>
        <Properties>
          <prop id="COBIFiles" value="C:\COBI.wms\Files"/>
          <prop id="COBILogs" value="C:\COBI.wms\Logs"/>
          <prop id="COBIEnablePDNDraft" value="0"/>
          <prop id="COBIRemPrtPath" value=""/>
        </Properties>
        <xsl:call-template name="setB1ifSysTypeAndLocalProps">
          <xsl:with-param name="biu">cobi.wms.v1.log</xsl:with-param>
          <xsl:with-param name="snd">
            <xsl:value-of select="/vpf:Msg/vpf:Header/vpf:Sender/@Id"/>
          </xsl:with-param>
          <xsl:with-param name="rcv">
            <xsl:value-of select="/vpf:Msg/vpf:Header/vpf:ReceiverList/vpf:Receiver[./@handover='P']/@Id"/>
          </xsl:with-param>
          <xsl:with-param name="sid">cobi.wms</xsl:with-param>
          <xsl:with-param name="offline">
            <xsl:value-of select="$offline"/>
          </xsl:with-param>
        </xsl:call-template>
        <VarProperties/>
      </Header>
      <xsl:copy-of select="/vpf:Msg/vpf:Body"/>
    </Msg>
  </xsl:template>
  <xsl:include href="../../com.sap.b1i.vplatform.runtime/vGeneral/setSysTypeAndLocalProps.xsl"/>
  <xsl:include href="../../com.sap.b1i.system.lib/xsl/string.xsl"/>
</xsl:stylesheet>
