<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:b1e="urn:com.sap.b1i.sim:b1event" xmlns:b1ie="urn:com.sap.b1i.sim:b1ievent" xmlns:b1im="urn:com.sap.b1i.sim:b1imessage" xmlns:bfa="urn:com.sap.b1i.bizprocessor:bizatoms" xmlns:jdbc="urn:com.sap.b1i.adapter:jdbcadapter" xmlns:js="com.sap.b1i.bpc_tools.Javascript" xmlns:rfc="urn:sap-com:document:sap:rfc:functions" xmlns:sim="urn:com.sap.b1i.sim:entity" xmlns:uplt="urn:com.sap.b1i.xcellerator:upltdoc" xmlns:utils2="com.sap.b1i.bpc_tools.Utilities" xmlns:vpf="urn:com.sap.b1i.vplatform:entity" xmlns:xci="urn:com.sap.b1i.xcellerator:intdoc" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" bfa:force="" vpf:force="" jdbc:force="" rfc:force="" b1ie:force="" b1e:force="" xci:force="" sim:force="" utils2:force="" b1im:force="" uplt:force="" js:force="">
  <xsl:output method="xml" encoding="UTF-8" indent="yes"/>
  <xsl:param name="atom"/>
  <xsl:param name="sessionid"/>
  <xsl:variable name="msg" select="/vpf:Msg/vpf:Body/vpf:Payload[./@Role='S']"/>
  <xsl:variable name="vpSender" select="/vpf:Msg/vpf:Header/vpf:Sender/@Id"/>
  <xsl:variable name="vpObject" select="/vpf:Msg/vpf:Header/vpf:Sender/@ObjId"/>
  <xsl:variable name="vpReceiver" select="/vpf:Msg/vpf:Header/vpf:ReceiverList/vpf:Receiver[./@handover='P']/@Id"/>
  <xsl:variable name="vpCOBIAppVersion" select="/vpf:Msg/vpf:Header/vpf:Variables/vpf:var[./@id='COBIAppVersion']/@value"/>
  <xsl:variable name="vpCOBIDeviceId" select="/vpf:Msg/vpf:Header/vpf:Variables/vpf:var[./@id='COBIDeviceId']/@value"/>
  <xsl:variable name="vpCOBIProfile" select="/vpf:Msg/vpf:Header/vpf:Variables/vpf:var[./@id='COBIProfile']/@value"/>
  <xsl:variable name="vpCOBISysId" select="/vpf:Msg/vpf:Header/vpf:Variables/vpf:var[./@id='COBISysId']/@value"/>
  <xsl:variable name="vpCOBIUserId" select="/vpf:Msg/vpf:Header/vpf:Variables/vpf:var[./@id='COBIUserId']/@value"/>
  <xsl:variable name="vpCOBIFiles" select="/vpf:Msg/vpf:Header/vpf:Properties/vpf:prop[./@id='COBIFiles']/@value"/>
  <xsl:variable name="vpCOBILogs" select="/vpf:Msg/vpf:Header/vpf:Properties/vpf:prop[./@id='COBILogs']/@value"/>
  <xsl:variable name="vpCOBIEnablePDNDraft" select="/vpf:Msg/vpf:Header/vpf:Properties/vpf:prop[./@id='COBIEnablePDNDraft']/@value"/>
  <xsl:variable name="vpCOBIRemPrtPath" select="/vpf:Msg/vpf:Header/vpf:Properties/vpf:prop[./@id='COBIRemPrtPath']/@value"/>
  <xsl:template match="/">
    <xsl:variable name="vptsDoc" select="document('/com.sap.b1i.internal/xml/timestamp')"/>
    <xsl:variable name="vpts" select="concat($vptsDoc/*/@year,'/',$vptsDoc/*/@month,'/',$vptsDoc/*/@date,' ',$vptsDoc/*/@hour,':',$vptsDoc/*/@minute,':',$vptsDoc/*/@second)"/>
    <Msg xmlns="urn:com.sap.b1i.vplatform:entity">
      <xsl:copy-of select="/vpf:Msg/@*"/>
      <xsl:copy-of select="/vpf:Msg/vpf:Header"/>
      <Body>
        <xsl:copy-of select="/vpf:Msg/vpf:Body/*"/>
        <Payload Role="X" id="{$atom}">
          <xsl:call-template name="transform"/>
        </Payload>
      </Body>
    </Msg>
  </xsl:template>
  <xsl:template name="transform">
    <xsl:variable name="lines" select="/vpf:Msg/vpf:Body/vpf:Payload[@id='atom14']/lines"/>
    <xsl:variable name="order" select="/vpf:Msg/vpf:Body/vpf:Payload[@id='atom13']/BOM/BO"/>
    <xsl:choose>
      <xsl:when test="//COBIError"/>
      <xsl:when test="not($order)">
        <COBIError/>
      </xsl:when>
      <xsl:otherwise>
        <Documents>
          <row>
            <U_CWMS_Updater>
              <xsl:value-of select="$vpCOBIUserId"/>
            </U_CWMS_Updater>
            <U_CWMS_UpdaterDevice>
              <xsl:value-of select="$vpCOBIDeviceId"/>
            </U_CWMS_UpdaterDevice>
          </row>
        </Documents>
        <BatchNumbers>
          <xsl:if test="$vpCOBIProfile = 'CHEESE'">
            <xsl:copy-of select="$order/BatchNumbers/row"/>
          </xsl:if>
          <xsl:if test="$vpCOBIProfile != 'CHEESE'">
            <xsl:for-each select="$order/BatchNumbers/row">
              <xsl:variable name="batches" select="$lines/line[baseDocLine = current()/BaseLineNumber]/batches/batch"/>
              <xsl:if test="not($batches[batchNumber = current()/BatchNumber])">
                <row>
                  <xsl:copy-of select="BaseLineNumber"/>
                  <xsl:copy-of select="BatchNumber"/>
                  <Quantity>0</Quantity>
                </row>
              </xsl:if>
            </xsl:for-each>
          </xsl:if>
          <xsl:for-each select="$lines/line/batches/batch">
            <row>
              <BaseLineNumber>
                <xsl:value-of select="../../baseDocLine"/>
              </BaseLineNumber>
              <BatchNumber>
                <xsl:value-of select="batchNumber"/>
              </BatchNumber>
              <Quantity>
                <xsl:value-of select="assignedQuantity"/>
              </Quantity>
            </row>
          </xsl:for-each>
        </BatchNumbers>
        <SerialNumbers>
          <xsl:if test="$vpCOBIProfile = 'CHEESE'">
            <xsl:copy-of select="$order/SerialNumbers/row"/>
          </xsl:if>
          <xsl:if test="$vpCOBIProfile != 'CHEESE'">
            <xsl:for-each select="$order/SerialNumbers/row">
              <xsl:variable name="serials" select="$lines/line[baseDocLine = current()/BaseLineNumber]/serials/serial"/>
              <xsl:if test="not($serials[serialNumber = current()/InternalSerialNumber])">
                <row>
                  <xsl:copy-of select="BaseLineNumber"/>
                  <xsl:copy-of select="SystemSerialNumber"/>
                  <xsl:copy-of select="InternalSerialNumber"/>
                  <Quantity>0</Quantity>
                </row>
              </xsl:if>
            </xsl:for-each>
          </xsl:if>
          <xsl:for-each select="$lines/line/serials/serial">
            <row>
              <BaseLineNumber>
                <xsl:value-of select="../../baseDocLine"/>
              </BaseLineNumber>
              <xsl:if test="systemNumber">
                <SystemSerialNumber>
                  <xsl:value-of select="systemNumber"/>
                </SystemSerialNumber>
              </xsl:if>
              <InternalSerialNumber>
                <xsl:value-of select="serialNumber"/>
              </InternalSerialNumber>
            </row>
          </xsl:for-each>
        </SerialNumbers>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
</xsl:stylesheet>
